@@ -189,9 +189,7 @@ void CliUnarchiverTest::testList()
     QCOMPARE(entry->property("compressedSize").toULongLong(), expectedCompressedSize);
 
     QFETCH(QString, expectedTimestamp);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
     QEXPECT_FAIL("", "Something changed since Qt 5.11, needs investigation.", Continue);
-#endif
     QCOMPARE(entry->property("timestamp").toString(), expectedTimestamp);
 
     plugin->deleteLater();
