@@ -125,11 +125,7 @@ void InfoPanel::setIndex(const QModelIndex& index)
             }
         }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        const QStringList nameParts = entry->fullPath().split(QLatin1Char( '/' ), QString::SkipEmptyParts);
-#else
         const QStringList nameParts = entry->fullPath().split(QLatin1Char( '/' ), Qt::SkipEmptyParts);
-#endif
         const QString name = (nameParts.count() > 0) ? nameParts.last() : entry->fullPath();
         fileName->setText(name);
 
